summaryrefslogtreecommitdiffstats
path: root/hv-collector-domain
diff options
context:
space:
mode:
Diffstat (limited to 'hv-collector-domain')
-rw-r--r--hv-collector-domain/src/main/kotlin/org/onap/dcae/collectors/veshv/domain/wire_frame.kt4
-rw-r--r--hv-collector-domain/src/test/kotlin/org/onap/dcae/collectors/veshv/domain/WireFrameCodecsTest.kt8
2 files changed, 6 insertions, 6 deletions
diff --git a/hv-collector-domain/src/test/kotlin/org/onap/dcae/collectors/veshv/domain/WireFrameCodecsTest.kt b/hv-collector-domain/src/test/kotlin/org/onap/dcae/collectors/veshv/domain/WireFrameCodecsTest.kt
index 988789d2..6756bf82 100644
--- a/hv-collector-domain/src/test/kotlin/org/onap/dcae/collectors/veshv/domain/WireFrameCodecsTest.kt
+++ b/hv-collector-domain/src/test/kotlin/org/onap/dcae/collectors/veshv/domain/WireFrameCodecsTest.kt
@@ -183,16 +183,16 @@ object WireFrameCodecsTest : Spek({
it("should return error when payload message header does not fit") {
val buff = Unpooled.buffer()
- .writeByte(0xFF)
+ .writeByte(0xAA)
.writeBytes("MOMOM".toByteArray())
decoder.decodeFirst(buff).assertFailedWithError { it.isInstanceOf(MissingWireFrameHeaderBytes::class.java) }
assertBufferIntact(buff)
}
- it("should return error when length looks ok but first byte is not 0xFF") {
+ it("should return error when length looks ok but first byte is not 0xAA") {
val buff = Unpooled.buffer()
- .writeByte(0x69)
+ .writeByte(0xFF)
.writeBytes("some garbage".toByteArray())
decoder.decodeFirst(buff).assertFailedWithError { it.isInstanceOf(InvalidWireFrameMarker::class.java) }
@@ -262,7 +262,7 @@ object WireFrameCodecsTest : Spek({
payloadSize = payload.size)
- assertTrue(decoder.decodeFirst(encoder.encode(input).writeByte(0xFF)).isRight())
+ assertTrue(decoder.decodeFirst(encoder.encode(input).writeByte(0xAA)).isRight())
}
}
}
diff --git a/hv-collector-domain/src/main/kotlin/org/onap/dcae/collectors/veshv/domain/wire_frame.kt b/hv-collector-domain/src/main/kotlin/org/onap/dcae/collectors/veshv/domain/wire_frame.kt
index 06ca9383..036888e1 100644
--- a/hv-collector-domain/src/main/kotlin/org/onap/dcae/collectors/veshv/domain/wire_frame.kt
+++ b/hv-collector-domain/src/main/kotlin/org/onap/dcae/collectors/veshv/domain/wire_frame.kt
@@ -26,7 +26,7 @@ package org.onap.dcae.collectors.veshv.domain
* ```
* -- Precedes every HV-VES message
* Header ::= SEQUENCE {
* magic INTEGER (0..255), – always 0xFF, identifies extended header usage
* versionMajor INTEGER (0..255), – major interface v, forward incompatible with previous major v
* versionMinor INTEGER (0..255), – minor interface v, forward compatible with previous minor v
* reserved OCTET STRING (SIZE (3)), – reserved for future use
@@ -58,7 +58,7 @@ data class WireFrameMessage(val payload: ByteData,
&& payload.size() == payloadSize
companion object {
- const val MARKER_BYTE: Short = 0xFF
+ const val MARKER_BYTE: Short = 0xAA
const val RESERVED_BYTE_COUNT: Int = 3
const val SUPPORTED_VERSION_MAJOR: Short = 1
@@ -26,7 +26,7 @@ package org.onap.dcae.collectors.veshv.domain
* -- Precedes every HV-VES message
* Header ::= SEQUENCE {
- * magic INTEGER (0..255), – always 0xFF, identifies extended header usage
+ * magic INTEGER (0..255), – always 0xAA, identifies extended header usage
* versionMajor INTEGER (0..255), – major interface v, forward incompatible with previous major v
* versionMinor INTEGER (0..255), – minor interface v, forward compatible with previous minor v